otcextensions.sdk.dcs.v1.restore
=================================

.. automodule:: otcextensions.sdk.dcs.v1.restore

The DCS Restore Class
---------------------

The ``Restore`` class inherits from
:class:`~otcextensions.sdk.sdk_resource.Resource`.

.. autoclass:: otcextensions.sdk.dcs.v1.restore.Restore
   :members:
